# nCoV


Get instant information about 2019-nCoV


`nCoV` 是一个可以在命令行查询实时新型冠状病毒疫情信息的爬虫应用



### 使用方式 Usage

```
Usage: nCoV [OPTIONS]

Options:
  -o      Output the overall data of China
  -d      Output detailed data of all provinces and some cities
  -a      Output all data. overall --> detailed
  --help  Show this message and exit.
```


### 安装 Install

```
$ pip install nCoV
```


### License

[MIT](https://github.com/EthanGeekFan/nCoV/blob/master/LICENSE)
